@@ -23,12 +23,10 @@
 
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
-const Gettext = imports.gettext;
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const GtkClutter = imports.gi.GtkClutter;
 const Lang = imports.lang;
-const _ = imports.gettext.gettext;
 
 const CheckIn = imports.checkIn;
 const Format = imports.format;
@@ -36,7 +34,6 @@ const Geoclue = imports.geoclue;
 const GeocodeService = imports.geocodeService;
 const MainWindow = imports.mainWindow;
 const NotificationManager = imports.notificationManager;
-const Path = imports.path;
 const PlaceStore = imports.placeStore;
 const RouteService = imports.routeService;
 const Settings = imports.settings;
@@ -74,9 +71,6 @@ const Application = new Lang.Class({
     },
 
     _init: function() {
-        Gettext.bindtextdomain('gnome-maps', Path.LOCALE_DIR);
-        Gettext.textdomain('gnome-maps');
-        GLib.set_prgname('gnome-maps');
         /* Translators: This is the program name. */
         GLib.set_application_name(_("Maps"));
 
@@ -115,7 +109,7 @@ const Application = new Lang.Class({
 
     _initAppMenu: function() {
         let builder = new Gtk.Builder();
-        builder.add_from_resource('/org/gnome/maps/app-menu.ui');
+        builder.add_from_resource('/org/gnome/Maps/ui/app-menu.ui');
 
         let menu = builder.get_object('app-menu');
         this.set_app_menu(menu);
@@ -123,11 +117,10 @@ const Application = new Lang.Class({
 
     vfunc_startup: function() {
         this.parent();
-        String.prototype.format = Format.format;
 
         GtkClutter.init(null);
 
-        Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/maps/application.css'));
+        Utils.loadStyleSheet(Gio.file_new_for_uri('resource:///org/gnome/Maps/application.css'));
 
         application = this;
         this._initServices();
@@ -141,7 +134,7 @@ const Application = new Lang.Class({
     },
 
     _initServices: function() {
-        settings       = new Settings.Settings('org.gnome.maps');
+        settings       = Settings.getSettings('org.gnome.Maps');
         routeService   = new RouteService.GraphHopper();
         geoclue        = new Geoclue.Geoclue();
         geocodeService = new GeocodeService.GeocodeService();
@@ -155,7 +148,8 @@ const Application = new Lang.Class({
         if (this._mainWindow)
             return;
 
-        Gtk.IconTheme.get_default().append_search_path(Path.ICONS_DIR);
+        Gtk.IconTheme.get_default().append_search_path(GLib.build_filenamev([pkg.pkgdatadir,
+                                                                             'icons']));
         let overlay = new Gtk.Overlay({ visible: true, can_focus: false });
         notificationManager = new NotificationManager.NotificationManager(overlay);
         this._mainWindow = new MainWindow.MainWindow(this, overlay);
