@@ -31,7 +31,6 @@ const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Signals = imports.signals;
 const Soup = imports.gi.Soup;
-const _ = imports.gettext.gettext;
 
 const METRIC_SYSTEM = 1;
 const IMPERIAL_SYSTEM = 2;
@@ -166,10 +165,10 @@ function activateAction(appId, action, parameter, timestamp) {
                           });
 }
 
-function CreateActorFromIconName(name) {
+function CreateActorFromIconName(name, size) {
     try {
         let theme = Gtk.IconTheme.get_default();
-        let pixbuf = theme.load_icon(name, 0, 0);
+        let pixbuf = theme.load_icon(name, size, 0);
         let image = new Clutter.Image();
         image.set_data(pixbuf.get_pixels(),
                        Cogl.PixelFormat.RGBA_8888,
@@ -196,7 +195,7 @@ function dashedToCamelCase(name) {
 
 function getUIObject(res, ids) {
     let builder = new Gtk.Builder();
-    builder.add_from_resource('/org/gnome/maps/' + res + '.ui');
+    builder.add_from_resource('/org/gnome/Maps/ui/' + res + '.ui');
     let ret = {};
     ids.forEach(function(id) {
         ret[dashedToCamelCase(id)] = builder.get_object(id);
@@ -356,6 +355,8 @@ function prettyTime(time) {
         labelledTime += _("%f h").format(hours)+' ';
     if (minutes > 0)
         labelledTime += _("%f min").format(minutes);
+    if (hours === 0 && minutes === 0)
+        labelledTime = _("%f s").format(seconds);
     return labelledTime;
 }
 
